accounts_model
library
Classes
-
AccountModel
-
Holds properties of SIP Account model
-
AccountsModel
-
Accounts list model (contains list of accounts, methods for managing them, handlers of library events)
-
Codec
-
Helper class for manipulating account' scodec settings
-
InitData
-
Holds lists of parameters using for initialization sipconnect module
-
VideoData
-
Holds video capturer params
-
VoiceMailModel
-
VoiceMailModel
Enums
-
RegState
-
Account's registration state
-
SecureMedia
-
SecureMedia options (audio/video encryption setting)
-
UpgradeToVideoMode
-
UpgradeToVideo modes (behavior when rceived INVITE with video SDP)
Typedefs
-
SaveChangesCallback
= void Function(String jsonStr)
-
Model invokes this callback when has changes which should be saved by the app