AccountModel class

Holds properties of SIP Account model

Constructors

AccountModel({String sipServer = "", String sipExtension = "", String sipPassword = "", int? expireTime})
AccountModel.cloneOrCreateNew(AccountModel? inAcc)
Returns copy of the input account or new account when input is null
factory
AccountModel.fromJson(Map<String, dynamic> jsonMap)
Creates instance of AccountModel with values read from json
factory

Properties

aCodecs ↔ List<int>?
Selected audio codecs (use Codec.getCodecsList/Codec.getSelectedCodecsIds to retrive and set values)
getter/setter pair
displName ↔ String?
Display name (caller Id) which library sends in the To/From headers. Example: "displayName"sip:extension@server
getter/setter pair
expireTime ↔ int?
Registration expire time in seconds (how long server has to remember registration of this account). When app set 0 - registration disabled.
getter/setter pair
forceSipProxy ↔ bool?
Use specified proxy for all requests (by default disabled)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasSecureMedia → bool
Returns true when enabled audio/video encryption
no setter
iceEnabled ↔ bool?
Use ICE (establish connection by collect and exchange transport candidates, webrtc compatible mode, by default disabled).
getter/setter pair
instanceId ↔ String?
Unique instance ID of this account and device (set value using method 'genAccInstId', see more RFC 5626)
getter/setter pair
keepAliveTime ↔ int?
Timeout in seconds which library uses for sending short packets (prevents closing ports between device and server, by default 30)
getter/setter pair
myAccId ↔ int
Unique account id assigned by library (valid only during current session)
getter/setter pair
port ↔ int?
Local SIP port number for this account (by default 0 which means using random port)
getter/setter pair
regState ↔ RegState
Registration state
getter/setter pair
regText ↔ String
Registration text, got from SIP response, received fro, remote server
getter/setter pair
rewriteContactIp ↔ bool?
Enable rewrite IP address of Contact header with address got from received SIP response's 'Via/received=...'
getter/setter pair
ringTonePath ↔ String?
Path to the ringtone file which library will play when incoming call received
getter/setter pair
rtcpMuxEnabled ↔ bool?
Use RtcpMux (sending RTP and RTCP packets trough the same port, by default disabled).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureMedia ↔ SecureMedia?
Audio/video encryption setting (by default disabled)
getter/setter pair
sipAuthId ↔ String?
AuthId (used for authentification, in case when server requires specific user name which doesn't match 'sipExtension')
getter/setter pair
sipExtension ↔ String
SIP Extension (phone number, user)
getter/setter pair
sipPassword ↔ String
SIP Password (used for registration on server)
getter/setter pair
sipProxy ↔ String?
Proxy server (used when 'sipServer' can't be resolved by DNS or need to override destination, where to send SIP requests)
getter/setter pair
sipServer ↔ String
SIP Server (domain)
getter/setter pair
stunServer ↔ String?
STUN Server
getter/setter pair
tlsCaCertPath ↔ String?
Path to the CA certificate file which library will use for verify server's certificate when establishes TLS connection
getter/setter pair
tlsUseSipScheme ↔ bool?
Use 'sip' scheme when TLS transport selected (By default 'false', library uses 'sips' scheme)
getter/setter pair
transport ↔ SipTransport?
SIP transport for this account
getter/setter pair
turnPassword ↔ String?
TURN Password
getter/setter pair
turnServer ↔ String?
TURN Server
getter/setter pair
turnUser ↔ String?
TURN User
getter/setter pair
upgradeToVideo ↔ UpgradeToVideoMode?
Specify how to handle received INVITE with video SDP. (By default 'RecvOnly', accept remote video, don't send local)
getter/setter pair
uri → String
URI of this account
no setter
userAgent ↔ String?
UserAgent string which library sends in the 'User-Agent' header of SIP requests. Default value 'sipconnect'.
getter/setter pair
vCodecs ↔ List<int>?
Selected video codecs (use Codec.getCodecsList/Codec.getSelectedCodecsIds to retrive and set values)
getter/setter pair
verifyIncomingCall ↔ bool?
Enables verify SDP of the incoming call. When enabled and received call with SDP which can't be answered library silently rejects this call
getter/setter pair
xContactUriParams ↔ Map<String, String>?
List of custom params which should be added to Contact's URI
getter/setter pair
xheaders ↔ Map<String, String>?
List of custom headers/values which should be added to REGISTER request
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited