serviceClassName property

String? serviceClassName
getter/setter pair

Android only. Class name of the service which allows to customize notifications and implemented as part of the android app. Example: com.sipconnect.sipconnect_voip_sdk_example.MyNotifService

Implementation

String? serviceClassName;