SecureMedia enum

SecureMedia options (audio/video encryption setting)

Inheritance
Available extensions

Values

Disabled → const SecureMedia

Secure media disabled

const SecureMedia(PjsipConnectFlutter.kSecureMediaDisabled, "Disabled")
SdesSrtp → const SecureMedia

Encryption audio/video using SDES SRTP

const SecureMedia(PjsipConnectFlutter.kSecureMediaSdesSrtp, "SDES SRTP")
DtlsSrtp → const SecureMedia

Encryption audio/video using DTLS SRTP

const SecureMedia(PjsipConnectFlutter.kSecureMediaDtlsSrtp, "DTLS SRTP")

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
Value
final
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
User friendly name of the selected option
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(int val) → SecureMedia
Returns enum item which matches int constant

Constants

values → const List<SecureMedia>
A constant List of the values in this enum, in order of their declaration.