CallState enum

Call state

Inheritance
Available extensions

Values

dialing → const CallState

Outgoing call just initiated

const CallState(0, "Dialing")
proceeding → const CallState

Outgoing call in progress, received 100Trying or 180Ringing

const CallState(1, "Proceeding")
ringing → const CallState

Incoming call just received

const CallState(2, "Ringing")
rejecting → const CallState

Incoming call rejecting after invoke 'call.reject'

const CallState(3, "Rejecting")
accepting → const CallState

Incoming call accepting after invoke 'call.accept'

const CallState(4, "Accepting")
connected → const CallState

Call successfully established, RTP is flowing

const CallState(5, "Connected")
disconnecting → const CallState

Call disconnecting after invoke 'call.bye'

const CallState(6, "Disconnecting")
holding → const CallState

Call holding (renegotiating RTP stream states)

const CallState(7, "Holding")
held → const CallState

Call held, RTP is NOT flowing

const CallState(8, "Held")
transferring → const CallState

Call transferring

const CallState(9, "Transferring")
terminated → const CallState

Call terminated

const CallState(10, "Terminated")

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
Call state id
final
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
Call state name
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(int val) → CallState
Returns state which matches specified int value

Constants

values → const List<CallState>
A constant List of the values in this enum, in order of their declaration.