CdrModel class

CDR = CallDetailRecord model (contains attributes of recent call, serializes them to/from json)

Inheritance

Constructors

CdrModel()
CdrModel.fromCall(int myCallId, String accUri, String remoteExt, bool incoming, bool hasVideo)
CdrModel.fromJson(Map<String, dynamic> jsonMap)
Creates instance of CdrModel with values read from json
factory

Properties

accUri ↔ String
Account URI
getter/setter pair
connected ↔ bool
Was call connected
getter/setter pair
displName ↔ String
Display name (Contact name if resolved)
getter/setter pair
duration ↔ String
Duration of the call
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
hasVideo ↔ bool
Has call video
getter/setter pair
incoming ↔ bool
Was call incoming
getter/setter pair
madeAt ↔ DateTime
DateTime when call has been initiated/received
getter/setter pair
madeAtDate → String
Formatted string with date/time when call has been initiated/received
no setter
myCallId ↔ int
Id if the CallModel, generated this record
getter/setter pair
reason ↔ String
Data from the header 'Reason', received in the CANCEL/BYE request
getter/setter pair
remoteExt ↔ String
Phone number(extension) of remote side
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode ↔ int
Status code assigned when call ended
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toJson() → Map<String, dynamic>
Store model to json string
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited