remove method
Remote recent call item by its index in the list
Implementation
void remove(int index) {
if ((index >= 0) && (index < length)) {
_cdrItems.removeAt(index);
notifyListeners();
}
}
Remote recent call item by its index in the list
void remove(int index) {
if ((index >= 0) && (index < length)) {
_cdrItems.removeAt(index);
notifyListeners();
}
}