SipTransport enum

SipTransport enum. Using as argument of 'AccountModel.transport'

Inheritance
Available extensions

Values

udp → const SipTransport

Send SIP over UDP transport

const SipTransport(PjsipConnectFlutter.kSipTransportUdp, "UDP")
tcp → const SipTransport

Send SIP over TCP transport

const SipTransport(PjsipConnectFlutter.kSipTransportTcp, "TCP")
tls → const SipTransport

Send SIP over TLS transport

const SipTransport(PjsipConnectFlutter.kSipTransportTls, "TLS")

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
Value
final
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
User friendly name of the selected option
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(int val) → SipTransport
Create enum item from int value

Constants

values → const List<SipTransport>
A constant List of the values in this enum, in order of their declaration.