CallIncomingArg class

Helper class for handling 'onCallIncoming' event raised by library

Constructors

CallIncomingArg()

Properties

accId int
getter/setter pair
callId int
getter/setter pair
from String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to String
getter/setter pair
withVideo bool
getter/setter pair

Methods

fromMap(Map argsMap) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited