CallTerminatedArg class

Helper class for handling 'onCallTerminated' event raised by library

Constructors

CallTerminatedArg()

Properties

callId int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
getter/setter pair

Methods

fromMap(Map argsMap) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited