Inteface of the accounts model, allows others models to resolve accountUri from Id and vice versa
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAccId(
String uri) → int - Get accountId by its uri
-
getUri(
int accId) → String - Get accountUri by its id
-
hasSecureMedia(
int accId) → bool - Returns true if account with specified id enabled secure media
-
isUpgradeToVideoModeRecvOnly(
String uri) → bool - Returns true if account with specified id has 'upgradeToVideo' set to 'RecvOnly'
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshRegistration(
) → void - Refresh registration of the all accounts
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited