MessageSentStateArg class

Helper class for handling 'onMessageSentState' event raised by library

Constructors

MessageSentStateArg()

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageId ↔ int
getter/setter pair
response ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ bool
getter/setter pair

Methods

fromMap(Map argsMap) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited