acceptVideoUpgrade method
Accept requested upgrade of the call's media and specify is allowed to use video
Implementation
Future<void> acceptVideoUpgrade(int callId, bool withVideo) async {
return _platform.acceptVideoUpgrade(callId, withVideo);
}
Accept requested upgrade of the call's media and specify is allowed to use video
Future<void> acceptVideoUpgrade(int callId, bool withVideo) async {
return _platform.acceptVideoUpgrade(callId, withVideo);
}