kLocalVideoCallId constant
int
const kLocalVideoCallId
Special callId used for creating renderer of the local camera
Implementation
static const int kLocalVideoCallId = 0;
Special callId used for creating renderer of the local camera
static const int kLocalVideoCallId = 0;