makeConference method
Join all calls to conference (configures mixer gains and handles audio streams in way when each call can hear other calls)
Implementation
Future<void> makeConference() {
return _platform.makeConference();
}
Join all calls to conference (configures mixer gains and handles audio streams in way when each call can hear other calls)
Future<void> makeConference() {
return _platform.makeConference();
}