PushIncomingArg class

Helper class for handling 'onPushIncoming' event raised by library

Constructors

PushIncomingArg()

Properties

callUUID ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pushPayload ↔ Map<String, dynamic>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromMap(Map argsMap) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited