SubscriptionStateArg class

Helper class for handling 'onSubscriptionState' event raised by library

Constructors

SubscriptionStateArg()

Properties

hashCode → int
The hash code for this object.
no setterinherited
response ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ SubscriptionState
getter/setter pair
subscrId ↔ int
getter/setter pair

Methods

fromMap(Map argsMap) → bool
Returns true when even's atrributes parsed successfully
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited