VuMeterArg class

Helper class for handling 'onVuMeterLevel' event raised by library

Constructors

VuMeterArg()

Properties

hashCode int
The hash code for this object.
no setterinherited
micLevel int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spkLevel int
getter/setter pair

Methods

fromMap(Map argsMap) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited