RTCVideoValue class

Contains video frame attributes provided by native plugins

Constructors

RTCVideoValue({double width = 0.0, double height = 0.0, int rotation = 0})
const

Properties

aspectRatio → double
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double
Height of the video frame (pixels)
final
rotation → int
Rotation of the video frame (degrees: 0/90/180/270)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
Width of the video frame (pixels)
final

Methods

copyWith({double? width, double? height, int? rotation}) → RTCVideoValue
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

empty → const RTCVideoValue