makeConference method
Join all calls to conference (configures mixer to send sound from mic to all calls and play received sound from all calls to speaker)
Implementation
Future<void> makeConference() async {
try {
if (_confModeStarted) {
_logs?.print(
'Ending conference, switch mixer to call $_switchedCallId',
);
await PjsipConnectFlutter().switchToCall(_switchedCallId);
_confModeStarted = false;
} else {
_logs?.print('Joining all calls to conference');
await PjsipConnectFlutter().makeConference();
_confModeStarted = true;
}
} on PlatformException catch (err) {
_logs?.print('Can\'t make conference. Err: ${err.code} ${err.message}');
return Future.error((err.message == null) ? err.code : err.message!);
}
}