PjsipConnectFlutter class

Root of the library implementation

Constructors

PjsipConnectFlutter()
factory

Properties

accListener AccStateListener?
Account state listener
getter/setter pair
callListener CallStateListener?
Call state listener
getter/setter pair
dvcListener DevicesStateListener?
Device changes listener
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
messagesListener MessagesStateListener?
Messages listenerer
getter/setter pair
netListener NetStateListener?
Network state listener
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sipNotifyListener SipNotifyListener?
SipNotify listenerer
getter/setter pair
subscrListener SubscrStateListener?
Subscription state listener
getter/setter pair
trialListener TrialModeListener?
Trial mode listenerer
getter/setter pair
vuMeterListener VuMeterListener?
VuMeter listenerer
getter/setter pair

Methods

accept(int callId, bool withVideo) Future<void>
Accept incoming call specified by its id. Use 'withVideo' to set audio-only or video call
acceptVideoUpgrade(int callId, bool withVideo) Future<void>
Accept requested upgrade of the call's media and specify is allowed to use video
addAccount(AccountModel newAccount) Future<int?>
///////////////////////////////////////////////////////////////////////////////////// Add new account, return unique id assigned by library
addSubscription(SubscriptionModel newSubscription) Future<int?>
Add new subscription (sends SUBSCRIBE request)
bye(int callId) Future<void>
End specified call
deleteAccount(int accId) Future<void>
Delete account specified by its id
deleteSubscription(int subscriptionId) Future<void>
Delete subscription
endCallKitCall(String callkit_CallUUID) Future<void>?
End CallKit call specified by its UUID (Allowed to use only when missed SIP signalling for that call)
genAccInstId() Future<String?>
Generate unique instance id. Used as value of AccountModel.instanceId
getCallKitCallUUID(int sip_callId) Future<String?>?
Get CallKit call UUID assigned with SIP callId (iOS only)
getHoldState(int callId) Future<int?>
Get hold state of the specified call
getPlayoutDevice(int index) Future<MediaDevice?>
Get speaker device details by its index
getPlayoutDevices() Future<int?>
Get number of avialable spekaer devices
getPushKitToken() Future<String?>?
Get PushKit token (iOS only)
getRecordingDevice(int index) Future<MediaDevice?>
Get microphone device details by its index
getRecordingDevices() Future<int?>
Get number of avialable microphone devices
getSipHeader(int callId, String headerName) Future<String?>
Get value of the SIP header from last received response
getStats(int callId) Future<String?>
Get call stats as json encoded string
getVideoDevice(int index) Future<MediaDevice?>
Get camera details by its index
getVideoDevices() Future<int?>
Get number of camera devices
hold(int callId) Future<void>
Hold/unhold specified call
homeFolder() Future<String?>
Path to the home folder created by library on device
initialize(InitData iniData, [ILogsModel? logsModel]) Future<void>
Initialize sipconnect module
invite(CallDestination destData) Future<int?>
Iniate new outgoing call
isForegroundMode() Future<bool?>?
Returns true if android service is running in foreground mode
makeConference() Future<void>
Join all calls to conference (configures mixer gains and handles audio streams in way when each call can hear other calls)
muteCam(int callId, bool mute) Future<void>
Mute camera for the specified call
muteMic(int callId, bool mute) Future<void>
Mute microphone for the specified call
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
playFile(int callId, String pathToMp3File, bool loop) Future<int?>
Play file to remote side of the specified call or local speaker (when specified 'callId=0')
playTone(int callId, String toneType, int durationMs) Future<int?>
Play tone to remote side of the specified call or local speaker (when specified 'callId=0')
recordFile(int callId, String pathToMp3File) Future<void>
Start recording sound, received from remote side to specified file
registerAccount(int accId, int expireTime) Future<void>
Reresh registration of account specified by its id
reject(int callId, int statusCode) Future<void>
Reject incoming call specified by its id, send response with status code
sendDtmf(int callId, String tones, int durationMs, int intertoneGapMs, [int method = kDtmfMethodRtp]) Future<void>
Send DTMF tone to remote side of the specified call
sendMessage(IPjsipConnectData messageData) Future<int?>
/////////////////////////////////////////////////////////////////////////////////////
setForegroundMode(bool enabled) Future<void>?
Set foreground mode of the android service (android only, allows app to stay in background)
setPlayoutDevice(int index) Future<void>
Set speaker device by its index
setRecordingDevice(int index) Future<void>
Set microphone device by its index
setVideoDevice(int index) Future<void>
Set camera device by its index
setVideoParams(VideoData videoData) Future<void>
Set video capturer params (common for all calls)
stopPlayFile(int playerId) Future<void>
Stop play file
stopRecordFile(int callId) Future<void>
Stop recording file
stopRingtone() Future<void>
Stop playing (mute) ringtone.
switchCamera() Future<void>?
Toggle front/back camera (iOS/Android platfroms only)
switchToCall(int callId) Future<void>
Switch to the selected call (sound from microphone is sending to this call and speaker plays sound received from this call)
syncCallsState(IPjsipConnectData callsData) Future<void>?
Provide calls state to the Android's service
toString() String
A string representation of this object.
inherited
transferAttended(int fromCallId, int toCallId) Future<void>
Make attended transfer of the call to specified call
transferBlind(int callId, String toExt) Future<void>
Make blind transfer of the call to specified extension
unInitialize(ILogsModel? logsModel) → void
UnInitialize sipconnect module
unRegisterAccount(int accId) Future<void>
Unregister account specified by its id
updateAccount(AccountModel updAccount) Future<void>
Update existing account with new attributes
updateCallKitCallDetails(String callkit_CallUUID, int? sip_callId, [String? localizedCallerName, String? genericHandle, bool? withVideo]) Future<void>?
Update CallKit call details (app can invoke it twice:
upgradeToVideo(int callId) Future<void>
Upgrade audio only call to audio+video
version() Future<String?>
Version (build date) of the library
versionCode() Future<int?>
Version code of the library (similar to Android API level)
videoRendererCreate() Future<int?>
Create video renderer
videoRendererDispose(int textureId) Future<void>
Dispose renderer
videoRendererSetSourceCall(int textureId, int callId) Future<void>
Set call whose video should be using as source for rendering

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance PjsipConnectFlutter
no setter

Constants

eDuplicateAccount → const int
eOK → const int
Error codes constants
eSubscrAlreadyExist → const int
kAudioCodecCN → const int
kAudioCodecDTMF → const int
kAudioCodecG722 → const int
kAudioCodecG729 → const int
kAudioCodecILBC → const int
kAudioCodecISAC16 → const int
kAudioCodecISAC32 → const int
kAudioCodecOpus → const int
Audio codec constants
kAudioCodecPCMA → const int
kAudioCodecPCMU → const int
kDtmfMethodInfo → const int
kDtmfMethodRtp → const int
DTMF method constants
kHoldStateLocal → const int
kHoldStateLocalAndRemote → const int
kHoldStateNone → const int
Hold state constants
kHoldStateRemote → const int
kLocalVideoCallId → const int
Special callId used for creating renderer of the local camera
kLogLevelDebug → const int
kLogLevelError → const int
kLogLevelInfo → const int
kLogLevelNone → const int
kLogLevelStack → const int
Log level constants
kLogLevelWarning → const int
kNetStateLost → const int
Network state constants
kNetStateRestored → const int
kNetStateSwitched → const int
kPlayerStateFailed → const int
kPlayerStateStarted → const int
Player state constants
kPlayerStateStopped → const int
kRegStateFailed → const int
kRegStateRemoved → const int
kRegStateSuccess → const int
Account registration state constants
kSecureMediaDisabled → const int
Secure media constants
kSecureMediaDtlsSrtp → const int
kSecureMediaSdesSrtp → const int
kSipTransportTcp → const int
kSipTransportTls → const int
kSipTransportUdp → const int
Sip transport constants
kSubscrStateCreated → const int
Subscription state constants
kSubscrStateDestroyed → const int
kSubscrStateUpdated → const int
kUpgradeToVideoInactive → const int
kUpgradeToVideoManual → const int
kUpgradeToVideoRecvOnly → const int
kUpgradeToVideoSendRecv → const int
Upgrade to video mode constants
kVideoCodecAV1 → const int
kVideoCodecH264 → const int
Video codec constants
kVideoCodecVP8 → const int
kVideoCodecVP9 → const int